@@ -85,6 +85,8 @@ void apply_server_settings(struct w *widgets)
 	if( strstr(line, "[") && ! strstr(line, "[global]") && ! commented(line) )
 	  break;
     }
+
+
     rewind(fp);
     
 
@@ -124,13 +126,13 @@ void apply_server_settings(struct w *widgets)
 	  info = g_strdup_printf(_("Auto configuration for \"user\" security level done.\nPlease review any changes.\n"));
 	else
 	if( sec_index == 1 )
-	  info = g_strdup_printf(_("Auto configuration for \"backup domain\" security level done.\nPlease review any changes.\n"));
+	  info = g_strdup_printf(_("Auto configuration for (BDC) \"backup domain\" security level done.\nUnlock and supply a samba password for the samba root account if needed.\n"));
 	else
 	if( sec_index == 2 )
-	  info = g_strdup_printf(_("Auto configuration for \"primary domain\" security level done.\nPlease review any changes.\n"));
+	  info = g_strdup_printf(_("Auto configuration for (PDC) \"primary domain\" security level done.\nConnect to this domain as root after giving it a samba password and unlocking it.\n"));
 	else
 	if( sec_index == 3 )
-	  info = g_strdup_printf(_("Auto configuration for \"Active directory\" security level done.\nPlease review any changes.\n"));
+	  info = g_strdup_printf(_("Auto configuration for (ADS) \"Active directory\" security level done.\nConnect to this domain as root after giving it a samba password and unlocking it.\n"));
 	else	
 	  info = g_strdup_printf(_("Error!!! Auto configuration for \"No\" security level done.\nPlease review any changes.\n"));
 	
