@@ -18,8 +18,8 @@
 */
 
 
-#ifndef GDHCPD_reread_conf_H
-#	define GDHCPD_reread_conf_H
+#ifndef GSAMBAD_reread_conf_H
+#	define GSAMBAD_reread_conf_H
 
 extern struct w *widgets;
 
