@@ -130,7 +130,7 @@ void add_standard_conf(struct w *widgets)
     strcat(buffer, "password level = 8\n");
 
     strcat(buffer, "username map = /etc/samba/smbusers\n");
-    strcat(buffer, "add user script = /usr/sbin/useradd -d /dev/null -g sambamachines -c 'Samba Machine Account' -s /dev/null -M %u\n");
+    strcat(buffer, "add user script = /usr/sbin/useradd -d /dev/null -g sambamachines -c 'Samba Machine Account' -s /dev/null -M '%u'\n");
 
     strcat(buffer, "smb passwd file = /etc/samba/smbpasswd\n");
     strcat(buffer, "encrypt passwords = yes\n");
@@ -410,12 +410,8 @@ void create_standard_conf_question(struct w *widgets)
 
     text = g_strconcat(
     _("GSAMBAD could not find SAMBAs configuration smb.conf or the current\n"),
-    _("configuration doesnt have all the features that GSAMBAD requires.\n"),
+    _("configuration doesnt have all the features that GSAMBAD requires.\n\n"),
 
-    // Fixme, remove these 2 lines in version 0.1.4
-    _("\nIf you have already answered this question on this computer then\n"),
-    _("press no. Its because this detection function was changed.\n\n"),
- 
     _("Do you want to overwrite the current samba configuration ?\n"),
 
     _("\t\t\t(If you dont know then press yes)\n"),
