@@ -18,8 +18,8 @@
 */
 
 
-#ifndef GDHCPD_status_update_H
-#   define GDHCPD_status_update_H
+#ifndef GSAMBAD_status_update_H
+#   define GSAMBAD_status_update_H
 
 extern struct w *widgets;
 
